<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../radialMap/map.cpp" line="108"/>
        <source>%1 files</source>
        <translation>%1 file</translation>
    </message>
    <message numerus="yes">
        <location filename="../../radialMap/map.cpp" line="204"/>
        <source>%n file(s), with an average size of %1</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RadialMap::Widget</name>
    <message numerus="yes">
        <location filename="../../radialMap/widgetEvents.cpp" line="194"/>
        <location filename="../../radialMap/widgetEvents.cpp" line="196"/>
        <source> into %n file(s)</source>
        <comment>file</comment>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Acquista la versione Ultimate per finanziare lo sviluppo del programma</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="293"/>
        <location filename="../../interface.cpp" line="314"/>
        <source>Register your key</source>
        <translation>Registrate la vostra chiave</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="525"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>File %1/%2, dimensione: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="832"/>
        <source>Copy list</source>
        <translation>Lista della copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="834"/>
        <source>Move list</source>
        <translation>Lista dello spostamento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1335"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono rilevati errori</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1336"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1337"/>
        <source>Always close</source>
        <translation>Chiudere sempre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1339"/>
        <source>File Name, 0KB</source>
        <translation>Nome del file, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1549"/>
        <location filename="../../interface.cpp" line="1561"/>
        <location filename="../../interface.cpp" line="1573"/>
        <source>Select a color</source>
        <translation>Seleziona colore</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1661"/>
        <location filename="../../interface.cpp" line="1672"/>
        <location filename="../../interface.cpp" line="1681"/>
        <source>%1 %2% of %3 into %4 files</source>
        <translation>%1 %2% di %3 in %4 file</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="320"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>Non chiudere se vengono rilevati errori</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="321"/>
        <source>Never close</source>
        <translation>Non chiudere mai</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="322"/>
        <source>Always close</source>
        <translation>Chiudere sempre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="518"/>
        <location filename="../../ThemesFactory.cpp" line="533"/>
        <location filename="../../ThemesFactory.cpp" line="548"/>
        <source>Select a color</source>
        <translation>Seleziona colore</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="420"/>
        <source>From:</source>
        <translation>Da:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="301"/>
        <source>&amp;More</source>
        <translation>&amp;Altro</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="321"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="482"/>
        <source>&amp;Skip</source>
        <translation>&amp;Salta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="493"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="389"/>
        <source>Close on transfer completion</source>
        <translation>Chiudi a trasferimento comletato</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="232"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="252"/>
        <source>100MB+</source>
        <translation>100MB+</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="527"/>
        <source>Limit copy speed to:</source>
        <translation>Limita velocità di copia a:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="570"/>
        <source>Transfer list</source>
        <translation>Lista dei trasferimenti</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="593"/>
        <source>Move the selected items to the top</source>
        <translation>Sposta in cima gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="619"/>
        <source>Move up the selected items</source>
        <translation>Sposta sopra gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="645"/>
        <source>Move down the selected items</source>
        <translation>Sposta sotto gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="671"/>
        <source>Move the selected items to the bottom</source>
        <translation>Sposta in coda gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="697"/>
        <source>Add file/folder</source>
        <translation>Aggiungi file/cartelle</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="726"/>
        <source>Delete the selected items</source>
        <translation>Elimina gli elementi selezionati</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="752"/>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="781"/>
        <source>Export the transfer list</source>
        <translation>Esporta la lista dei trasferimenti</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="807"/>
        <source>Import the transfer list</source>
        <translation>Importa la lista dei trasferimenti</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="862"/>
        <source>Previous</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="869"/>
        <source>Next</source>
        <translation>Successivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="904"/>
        <location filename="../../interface.ui" line="973"/>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="924"/>
        <source>Export the errors into transfer list</source>
        <translation>Esporta gli errori nella lista dei trasferimenti</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="963"/>
        <source>Source</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="968"/>
        <source>Destination</source>
        <translation>Destinazione</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="982"/>
        <source>Interface</source>
        <translation>Interfaccia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1028"/>
        <source>Add file</source>
        <translation>Aggiungi file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1037"/>
        <source>Add folder</source>
        <translation>Aggiungi cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1046"/>
        <source>Move file(s)</source>
        <translation>Sposta (i) file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1055"/>
        <source>Move folder</source>
        <translation>Sposta la cartella</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1064"/>
        <source>Copy file(s)</source>
        <translation>Copia (i) file</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="1073"/>
        <source>Copy folder</source>
        <translation>Copia cartella</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="293"/>
        <source>Show dual progression</source>
        <translation>Mostrare doppia progressione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="245"/>
        <source>Show speed as main information</source>
        <translation>Mostrare velocità come informazione principale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Utilizza</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="110"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Avvia con pulsante &quot;Altro&quot; attivo</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="57"/>
        <source>Minimize on close to systray</source>
        <translation>Alla chiusura riduci in area di notifica</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="80"/>
        <source>At the end of the copy</source>
        <translation>Al termine della copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="70"/>
        <location filename="../../themesOptions.ui" line="87"/>
        <source>Limit copy speed to</source>
        <translation>Limita velocità di copia a</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="117"/>
        <source>Start minimized</source>
        <translation>Avvia ridotto a icona</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="144"/>
        <source>Position at start</source>
        <translation>Posizione all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="239"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="332"/>
        <source>Click to edit the color</source>
        <translation>Clicca per modificare il colore</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="97"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="204"/>
        <source>Dark UI</source>
        <translation>Interfaccia utente scura</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="212"/>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="217"/>
        <source>Save as previous</source>
        <translation>Salva come il precedente</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="222"/>
        <source>At Center</source>
        <translation>Centrale</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Display</source>
        <translation>Visualizza</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="283"/>
        <source>Speed with progress bar</source>
        <translation>Velocità nella barra di progresso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="313"/>
        <source>Progression color</source>
        <translation>Colore della progressione</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="303"/>
        <source>Show progression in the title</source>
        <translation>Mostra progressione titolo</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Always on top</source>
        <translation>Sempre in primo piano</translation>
    </message>
</context>
</TS>
